@@ -66,13 +66,18 @@ class DatasetMgmt(metaclass=ABCMeta):
         self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
         pass
     
+    @abstractmethod
+    def write_dataset_count(self, path, count):
+        self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
+        pass
+        
     @abstractmethod
     def write(self, path, dataset): 
         self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
         pass
     
     @abstractmethod
-    def read_images(self, path): 
+    def read_images(self, path):# -> images, count: 
         self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
         pass
     
