@@ -1,7 +1,8 @@
+import os    
 import sys
 from .. import global_variable as gv
-from . import gcp_dataset_mgmt as gcp_dsmgmt
-from . import aws_dataset_mgmt as aws_dsmgmt
+from . import gcp_dataset_mgmt as gcp_tf_dsmgmt
+from . import aws_dataset_mgmt as aws_tf_dsmgmt
 #######################################################################
 # import new cloud package
 # Example:
@@ -15,6 +16,7 @@ class Storage():
     log = None
     dsmgmt = None
     dsmgmt_module = None
+    cloud_platform_type = None
     
     
     def __init__(self, global_variable, log):
@@ -27,20 +29,11 @@ class Storage():
         self.dsmgmt = self.dsmgmt_module.MiddleDatasetMgmt(self.gv, self.log)
 
         
-    def activate_cloud_platform(self, cloud_type):
-        if isinstance(self.gv.eCLOUD_TYPE.GCP, type(cloud_type)):
-            if self.gv.eCLOUD_TYPE.GCP == cloud_type:
-                self.__set_cloud_dataset_mgmt(gcp_dsmgmt)
-            if self.gv.eCLOUD_TYPE.AWS == cloud_type:
-                self.__set_cloud_dataset_mgmt(aws_dsmgmt)
-            #######################################################################   
-            # Add {new_cloud_type} activation code in here
-            # Example:
-            # if self.gv.eCLOUD_TYPE.{NEW_CLOUD_TYPE} == cloud_type
-            #     self.__set_cloud_dataset_mgmt({new_cloud_type}_dsmgmt)
-            #######################################################################
+    def activate_cloud_platform(self, cloud_platform_type):
+        if isinstance(self.gv.eCLOUD_TYPE.GCP, type(cloud_platform_type)):
+            self.cloud_platform_type = cloud_platform_type
         else: 
-            print("cloud_type error")
+            print("cloud_platform_type error")
 
     # dataset source type과 deeplearning framework type(tensorflow, pythorch)을 분리해야 함 
     def activate_dataset_source(self, dataset_source_type):
@@ -60,13 +53,36 @@ class Storage():
             
             
     def activate_deeplearning_framework(self, dl_framework_type):
-        pass
+        if isinstance(self.gv.eDEEPLEARNING_FRAMEWORK_TYPE.TENSRORFLOW, type(dl_framework_type)):
+            if isinstance(self.gv.eCLOUD_TYPE.GCP, type(self.cloud_platform_type)):
+                if self.gv.eCLOUD_TYPE.GCP == self.cloud_platform_type:
+                    if self.gv.eDEEPLEARNING_FRAMEWORK_TYPE.TENSRORFLOW == dl_framework_type:
+                        self.__set_cloud_dataset_mgmt(gcp_tf_dsmgmt)
+                    elif self.gv.eDEEPLEARNING_FRAMEWORK_TYPE.PYTORCH == dl_framework_type:
+                        self.__set_cloud_dataset_mgmt(gcp_tf_dsmgmt)  #pytorch로 수정 필요
+                if self.gv.eCLOUD_TYPE.AWS == self.cloud_platform_type:
+                    if self.gv.eDEEPLEARNING_FRAMEWORK_TYPE.TENSRORFLOW == dl_framework_type:
+                        self.__set_cloud_dataset_mgmt(aws_tf_dsmgmt)
+                    elif self.gv.eDEEPLEARNING_FRAMEWORK_TYPE.PYTORCH == dl_framework_type:
+                        self.__set_cloud_dataset_mgmt(aws_tf_dsmgmt) #pytorch로 수정 필요
+                #######################################################################   
+                # Add {NEW_CLOUD_TYPE} or {new NEW_DL_FRAMEWORK_TYPE} activation code in here
+                # Example:
+                # if self.gv.eCLOUD_TYPE.{NEW_CLOUD_TYPE} == self.cloud_platform_type:
+                #    if self.gv.eDEEPLEARNING_FRAMEWORK_TYPE.{NEW_DL_FRAMEWORK_TYPE} == dl_framework_type:
+                #         self.__set_cloud_dataset_mgmt({new_cloud_type}_{NEW_DL_FRAMEWORK_TYPE}_dsmgmt)
+                #######################################################################
+            else:
+                print("cloud_platform_type error")
+        else: 
+            print("deeplearning_framework error")
+   
     
-    
-    def activate_platform(self, cloud_type, dataset_source_type, dl_framework_type):
+    def activate_platform(self, cloud_type, dl_framework_type, dataset_source_type):
         self.activate_cloud_platform(cloud_type)
-        self.activate_dataset_source(dataset_source_type)
         self.activate_deeplearning_framework(dl_framework_type)
+        self.activate_dataset_source(dataset_source_type)
+
         
             
     def make_bucket(self, bucket_name):
@@ -84,10 +100,13 @@ class Storage():
 
         
     def write_dataset(self, path, dataset): 
+        print("a")
         self.dsmgmt.write(path, dataset)
+        print("b")
+        self.dsmgmt.write_dataset_count(path, len(dataset))
         
         
-    def read_images(self, path):
+    def read_images(self, path):# -> images, count:
         return self.dsmgmt.read_images(path)
     
     
